
<a id="readme-top"></a>


<br />
<div align="center">
  <a href="dev.thienhang.com">
    
  </a>

  <h3 align="center">Multiple data platform</h3>

  <p align="center">
    open@thienhang.com
    <br />
    <a href="https://python.thienhang.com"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://pypi.org/project/tian_core/">Pypi</a>
    ·
    <a href="https://open.thienhang.com">Website</a>
  </p>
</div>


